@@ -7,4 +7,5 @@ class MyClass:
         self.called += 1
 
     def printy(self):
-        print("Hello " + self.name + " for the " + self.called + " time.")
\ No newline at end of file
+        print("Hello " + self.name + " for the " + str(self.called) + " time.")
+        self.called += 1
